<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// E
	'explication_url_statique_ressources' => 'クーキーを使用せずに静的ファイル（画像、JS...）を提供できるURL。通常、サイトにも向ける代替サブドメインです。',

	// I
	'info_compresseur_titre' => '最適化と圧縮',
	'info_question_activer_compactage_css' => 'CSS',
	'info_question_activer_compactage_js' => 'スクリプト',
	'item_compresseur_css' => 'スタイルシートの圧縮を有効にする（CSS）',
	'item_compresseur_js' => 'スクリプト圧縮を有効にする（JavaScript ）',

	// L
	'label_url_statique_ressources' => 'リソースのURL',

	// T
	'texte_compacter_avertissement' => 'サイトの開発中にこれらのオプションを有効にしないように注意してください： 圧縮された要素はすべて読めなくなります。',
	'texte_compacter_script_css' => 'SPIPは、静的ファイルに保存するために、JavaScriptスクリプトとCSSスタイルシートを圧縮することが出来ます。これにより、サイトの表示速度が上がります。',
	'titre_compacter_script_css' => 'スクリプトとCSSの圧縮',
];
